@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) Stephan Arts 2009-2010 <stephan@xfce.org>
+ *  Copyright (c) Stephan Arts 2009-2011 <stephan@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,22 +45,9 @@ static void
 cb_rstto_preferences_dialog_bgcolor_override_toggled (GtkToggleButton *, gpointer);
 static void
 cb_rstto_preferences_dialog_bgcolor_color_set (GtkColorButton *, gpointer);
+
 static void
-cb_rstto_preferences_dialog_cache_check_button_toggled (GtkToggleButton *, gpointer);
-static void
-cb_rstto_preferences_dialog_cache_preload_check_button_toggled (GtkToggleButton *button, 
-                                                                gpointer user_data);
-static void
-cb_rstto_preferences_dialog_cache_spin_button_value_changed (GtkSpinButton *, gpointer);
-static void
-cb_rstto_preferences_dialog_image_preview_toggled (GtkToggleButton *button, 
-                                                      gpointer user_data);
-static void
-cb_rstto_preferences_dialog_no_scrollwheel_action_radio_button_toggled (GtkToggleButton *, gpointer);
-static void
-cb_rstto_preferences_dialog_zoom_scrollwheel_action_radio_button_toggled (GtkToggleButton *, gpointer);
-static void
-cb_rstto_preferences_dialog_switch_scrollwheel_action_radio_button_toggled (GtkToggleButton *, gpointer );
+cb_rstto_preferences_dialog_zoom_revert_check_button_toggled (GtkToggleButton *, gpointer);
 
 static void
 cb_rstto_preferences_dialog_hide_thumbnails_fullscreen_check_button_toggled (
@@ -68,12 +55,17 @@ cb_rstto_preferences_dialog_hide_thumbnails_fullscreen_check_button_toggled (
                                                         gpointer user_data);
 
 static void
-cb_rstto_preferences_dialog_open_entire_folder_check_button_toggled (GtkToggleButton *button, 
-                                                      gpointer user_data);
+cb_open_entire_folder_check_button_toggled (
+        GtkToggleButton *button, 
+        gpointer user_data);
 static void
-cb_rstto_preferences_dialog_wrap_images_check_button_toggled (GtkToggleButton *button, 
-                                                      gpointer user_data);
-
+cb_wrap_images_check_button_toggled (
+        GtkToggleButton *button, 
+        gpointer user_data);
+static void
+cb_maximize_on_startup_check_button_toggled (
+        GtkToggleButton *button, 
+        gpointer user_data);
 static void
 cb_rstto_preferences_dialog_slideshow_timeout_value_changed (GtkRange *, gpointer);
 
@@ -90,8 +82,6 @@ struct _RsttoPreferencesDialogPriv
         GtkWidget *bgcolor_hbox;
         GtkWidget *bgcolor_color_button;
         GtkWidget *bgcolor_override_check_button;
-
-        GtkWidget *image_preview_check_button;
     } display_tab;
 
     struct
@@ -108,10 +98,7 @@ struct _RsttoPreferencesDialogPriv
     {
         GtkWidget *scroll_frame;
         GtkWidget *scroll_vbox;
-        GtkWidget *no_scrollwheel_action_radio_button;
-        GtkWidget *zoom_scrollwheel_action_radio_button;
-        GtkWidget *switch_scrollwheel_action_radio_button;
-
+        GtkWidget *zoom_revert_check_button;
     } control_tab;
 
     struct
@@ -122,24 +109,11 @@ struct _RsttoPreferencesDialogPriv
 
         GtkWidget *startup_frame;
         GtkWidget *startup_vbox;
-        GtkWidget *resize_window_on_startup_check_button;
+        GtkWidget *maximize_window_on_startup_check_button;
         GtkWidget *open_entire_folder_check_button;
         GtkWidget *wrap_images_check_button;
     } behaviour_tab;
 
-    struct
-    {
-        GtkWidget *cache_frame;
-        GtkWidget *cache_vbox;
-        GtkWidget *cache_sub_vbox;
-        GtkWidget *cache_hbox;
-        GtkWidget *cache_size_label;
-        GtkWidget *cache_size_unit;
-        GtkWidget *cache_check_button;
-        GtkWidget *cache_alignment;
-        GtkWidget *cache_spin_button;
-        GtkWidget *cache_preload_check_button;
-    } cache_tab;
 };
 
 GType
@@ -171,16 +145,14 @@ rstto_preferences_dialog_get_type (void)
 static void
 rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
 {
-    guint uint_cache_size;
-    gboolean bool_preload_images;
-    gboolean bool_enable_cache;
+    gboolean bool_revert_zoom_direction;
     gboolean bool_bgcolor_override;
-    gchar *scrollwheel_primary_action;
     guint uint_slideshow_timeout;
     gboolean bool_hide_thumbnailbar_fullscreen;
     gboolean bool_show_preview;
     gboolean bool_open_entire_folder;
     gboolean bool_wrap_images;
+    gboolean bool_maximize_on_startup;
 
     GdkColor *bgcolor;
     GtkWidget *timeout_lbl, *timeout_hscale;
@@ -202,16 +174,13 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
 
     dialog->priv->settings = rstto_settings_new ();
     g_object_get (G_OBJECT (dialog->priv->settings),
-                  "cache-size", &uint_cache_size,
-                  "show-preview", &bool_show_preview,
-                  "preload-images", &bool_preload_images,
-                  "enable-cache", &bool_enable_cache,
+                  "revert-zoom-direction", &bool_revert_zoom_direction,
                   "bgcolor-override", &bool_bgcolor_override,
                   "bgcolor", &bgcolor,
-                  "scrollwheel-primary-action", &scrollwheel_primary_action,
                   "slideshow-timeout", &uint_slideshow_timeout,
                   "hide-thumbnailbar-fullscreen", &bool_hide_thumbnailbar_fullscreen,
                   "open-entire-folder", &bool_open_entire_folder,
+                  "maximize-on-startup", &bool_maximize_on_startup,
                   "wrap-images", &bool_wrap_images,
                   NULL);
 
@@ -254,13 +223,6 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
     g_signal_connect (G_OBJECT (dialog->priv->display_tab.bgcolor_color_button), 
                       "color-set", G_CALLBACK (cb_rstto_preferences_dialog_bgcolor_color_set), dialog);
 
-    dialog->priv->display_tab.image_preview_check_button = gtk_check_button_new_with_label (_("Show preview when loading image"));
-
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->display_tab.image_preview_check_button),
-                                  bool_show_preview);
-    g_signal_connect (G_OBJECT (dialog->priv->display_tab.image_preview_check_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_image_preview_toggled, dialog);
-
 /*******************/
 /** Slideshow tab **/
 /*******************/
@@ -312,43 +274,11 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
     dialog->priv->control_tab.scroll_frame = xfce_gtk_frame_box_new_with_content(_("Scrollwheel"), dialog->priv->control_tab.scroll_vbox);
     gtk_box_pack_start (GTK_BOX (control_main_vbox), dialog->priv->control_tab.scroll_frame, FALSE, FALSE, 0);
 
-    dialog->priv->control_tab.no_scrollwheel_action_radio_button = gtk_radio_button_new_with_label (NULL, _("No action"));
-    gtk_container_add (GTK_CONTAINER (dialog->priv->control_tab.scroll_vbox), dialog->priv->control_tab.no_scrollwheel_action_radio_button);
+    dialog->priv->control_tab.zoom_revert_check_button = gtk_check_button_new_with_label (_("Revert zoom direction"));
+    gtk_container_add (GTK_CONTAINER (dialog->priv->control_tab.scroll_vbox), dialog->priv->control_tab.zoom_revert_check_button);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->control_tab.zoom_revert_check_button), bool_revert_zoom_direction);
 
-
-    dialog->priv->control_tab.zoom_scrollwheel_action_radio_button = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (dialog->priv->control_tab.no_scrollwheel_action_radio_button), _("Zoom in and out"));
-    gtk_container_add (GTK_CONTAINER (dialog->priv->control_tab.scroll_vbox), dialog->priv->control_tab.zoom_scrollwheel_action_radio_button);
-
-    dialog->priv->control_tab.switch_scrollwheel_action_radio_button = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (dialog->priv->control_tab.no_scrollwheel_action_radio_button), _("Switch images"));
-    gtk_container_add (GTK_CONTAINER (dialog->priv->control_tab.scroll_vbox), dialog->priv->control_tab.switch_scrollwheel_action_radio_button);
-
-    if (scrollwheel_primary_action)
-    {
-        if (!strcmp (scrollwheel_primary_action, "zoom"))
-        {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->control_tab.zoom_scrollwheel_action_radio_button), TRUE);
-        } 
-        else if (!strcmp (scrollwheel_primary_action, "switch"))
-        {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->control_tab.switch_scrollwheel_action_radio_button), TRUE);
-        }
-        else
-        {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->control_tab.no_scrollwheel_action_radio_button), TRUE);
-        }
-    }
-    else
-    {
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->control_tab.no_scrollwheel_action_radio_button), TRUE);
-    }
-    
-
-    g_signal_connect (G_OBJECT (dialog->priv->control_tab.no_scrollwheel_action_radio_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_no_scrollwheel_action_radio_button_toggled, dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->control_tab.zoom_scrollwheel_action_radio_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_zoom_scrollwheel_action_radio_button_toggled, dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->control_tab.switch_scrollwheel_action_radio_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_switch_scrollwheel_action_radio_button_toggled, dialog);
+    g_signal_connect (G_OBJECT (dialog->priv->control_tab.zoom_revert_check_button), "toggled", (GCallback)cb_rstto_preferences_dialog_zoom_revert_check_button_toggled, dialog);
 /*******************/
 /** Behaviour tab **/
 /*******************/
@@ -369,102 +299,51 @@ rstto_preferences_dialog_init(RsttoPreferencesDialog *dialog)
     dialog->priv->behaviour_tab.startup_vbox = gtk_vbox_new(FALSE, 0);
     dialog->priv->behaviour_tab.startup_frame = xfce_gtk_frame_box_new_with_content(_("Startup"), dialog->priv->behaviour_tab.startup_vbox);
     gtk_box_pack_start (GTK_BOX (behaviour_main_vbox), dialog->priv->behaviour_tab.startup_frame, FALSE, FALSE, 0);
-    dialog->priv->behaviour_tab.resize_window_on_startup_check_button = gtk_check_button_new_with_label (_("Resize window to image on startup"));
-    gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.resize_window_on_startup_check_button);
-    gtk_widget_set_sensitive (dialog->priv->behaviour_tab.resize_window_on_startup_check_button, FALSE);
+    dialog->priv->behaviour_tab.maximize_window_on_startup_check_button = gtk_check_button_new_with_label (_("Maximize window on startup when opening an image"));
+    gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.maximize_window_on_startup_check_button);
+    gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.maximize_window_on_startup_check_button),
+            bool_maximize_on_startup);
 
     dialog->priv->behaviour_tab.open_entire_folder_check_button = gtk_check_button_new_with_label (_("Open entire folder on startup"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.open_entire_folder_check_button);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.open_entire_folder_check_button),
-                                  bool_open_entire_folder);
+    gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.open_entire_folder_check_button),
+            bool_open_entire_folder);
 
     dialog->priv->behaviour_tab.wrap_images_check_button = gtk_check_button_new_with_label (_("Wrap around images"));
     gtk_container_add (GTK_CONTAINER (dialog->priv->behaviour_tab.startup_vbox), dialog->priv->behaviour_tab.wrap_images_check_button);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->behaviour_tab.wrap_images_check_button),
                                   bool_wrap_images);
 
-    g_signal_connect (G_OBJECT (dialog->priv->behaviour_tab.open_entire_folder_check_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_open_entire_folder_check_button_toggled, dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->behaviour_tab.wrap_images_check_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_wrap_images_check_button_toggled, dialog);
+    g_signal_connect (
+            G_OBJECT (dialog->priv->behaviour_tab.open_entire_folder_check_button), 
+            "toggled",
+            (GCallback)cb_open_entire_folder_check_button_toggled,
+            dialog);
+    g_signal_connect (
+            G_OBJECT (dialog->priv->behaviour_tab.wrap_images_check_button), 
+            "toggled",
+            (GCallback)cb_wrap_images_check_button_toggled,
+            dialog);
+    g_signal_connect (
+            G_OBJECT
+(dialog->priv->behaviour_tab.maximize_window_on_startup_check_button), 
+            "toggled",
+            (GCallback)cb_maximize_on_startup_check_button_toggled,
+            dialog);
 
 
 
-/***************/
-/** Cache tab **/
-/***************/
-    cache_main_vbox = gtk_vbox_new(FALSE, 0);
-    cache_main_lbl = gtk_label_new(_("Memory"));
-    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), cache_main_vbox, cache_main_lbl);
-
-
-/** Image-cache frame */
-    dialog->priv->cache_tab.cache_vbox = gtk_vbox_new(FALSE, 0);
-    dialog->priv->cache_tab.cache_frame = xfce_gtk_frame_box_new_with_content(_("Image cache"),
-                                                                                 dialog->priv->cache_tab.cache_vbox);
-    gtk_box_pack_start (GTK_BOX (cache_main_vbox), dialog->priv->cache_tab.cache_frame, FALSE, FALSE, 0);
-
-    cache_adjustment = gtk_adjustment_new (RSTTO_DEFAULT_CACHE_SIZE, RSTTO_MIN_CACHE_SIZE, 4096, 1, 0, 0);
-
-    dialog->priv->cache_tab.cache_size_label = gtk_label_new (_("Cache size"));
-    dialog->priv->cache_tab.cache_size_unit = gtk_label_new (_("MB"));
-    dialog->priv->cache_tab.cache_hbox = gtk_hbox_new (FALSE, 4);
-    dialog->priv->cache_tab.cache_sub_vbox = gtk_vbox_new (FALSE, 4);
-    dialog->priv->cache_tab.cache_check_button = gtk_check_button_new_with_label (_("Enable cache"));
-    dialog->priv->cache_tab.cache_alignment = gtk_alignment_new (0, 0, 1, 1);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (dialog->priv->cache_tab.cache_alignment), 0, 0, 20, 0);
-    dialog->priv->cache_tab.cache_spin_button = gtk_spin_button_new(GTK_ADJUSTMENT(cache_adjustment), 1.0, 0);
-
-    dialog->priv->cache_tab.cache_preload_check_button = gtk_check_button_new_with_label (_("Enable preloading"));
-
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_hbox), 
-                                 dialog->priv->cache_tab.cache_size_label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_hbox), 
-                                 dialog->priv->cache_tab.cache_spin_button, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_hbox), 
-                                 dialog->priv->cache_tab.cache_size_unit, FALSE, FALSE, 0);
-
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_vbox), 
-                                 dialog->priv->cache_tab.cache_check_button, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_vbox), 
-                                 dialog->priv->cache_tab.cache_alignment, FALSE, FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (dialog->priv->cache_tab.cache_alignment),
-                                      dialog->priv->cache_tab.cache_sub_vbox);
-
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_sub_vbox), 
-                                 dialog->priv->cache_tab.cache_hbox, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->cache_tab.cache_sub_vbox), 
-                                 dialog->priv->cache_tab.cache_preload_check_button, FALSE, FALSE, 0);
-    
-    /* set current value */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->cache_tab.cache_check_button),
-                                  bool_enable_cache);
-    gtk_widget_set_sensitive (GTK_WIDGET (dialog->priv->cache_tab.cache_sub_vbox),
-                              bool_enable_cache);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->cache_tab.cache_preload_check_button),
-                                  bool_preload_images);
-    if (uint_cache_size < RSTTO_MIN_CACHE_SIZE)
-    {
-        gtk_adjustment_set_value (GTK_ADJUSTMENT (cache_adjustment), RSTTO_DEFAULT_CACHE_SIZE);
-    }
-    else
-    {
-        gtk_adjustment_set_value (GTK_ADJUSTMENT (cache_adjustment), uint_cache_size);
-    }
-
-    /* connect signals */
-    g_signal_connect (G_OBJECT (dialog->priv->cache_tab.cache_check_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_cache_check_button_toggled, dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->cache_tab.cache_check_button), 
-                      "toggled", (GCallback)cb_rstto_preferences_dialog_cache_preload_check_button_toggled, dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->cache_tab.cache_spin_button), 
-                      "value-changed", (GCallback)cb_rstto_preferences_dialog_cache_spin_button_value_changed, dialog);
-
 /********************************************/
     gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), notebook);
     gtk_widget_show_all (notebook);
 
+    /* Window should not be resizable */
+    gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+
     gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_OK);
+
 }
 
 static void
@@ -538,112 +417,12 @@ cb_rstto_preferences_dialog_bgcolor_color_set (GtkColorButton *button, gpointer
 }
 
 static void
-cb_rstto_preferences_dialog_cache_check_button_toggled (GtkToggleButton *button, 
-                                                        gpointer user_data)
+cb_rstto_preferences_dialog_zoom_revert_check_button_toggled (GtkToggleButton *button, 
+                                                              gpointer user_data)
 {
     RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
 
-    GValue value = {0, };
-    g_value_init (&value, G_TYPE_BOOLEAN);
-
-    if (gtk_toggle_button_get_active (button))
-    {
-        g_value_set_boolean (&value, TRUE);
-    	gtk_widget_set_sensitive (GTK_WIDGET (dialog->priv->cache_tab.cache_sub_vbox), TRUE);
-    }
-    else
-    {
-        g_value_set_boolean (&value, FALSE);
-    	gtk_widget_set_sensitive (GTK_WIDGET (dialog->priv->cache_tab.cache_sub_vbox), FALSE);
-    }
-    
-    g_object_set_property (G_OBJECT (dialog->priv->settings), "enable-cache", &value);
-
-    g_value_unset (&value);
-
-}
-
-static void
-cb_rstto_preferences_dialog_cache_preload_check_button_toggled (GtkToggleButton *button, 
-                                                                gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    GValue value = {0, };
-    g_value_init (&value, G_TYPE_BOOLEAN);
-    if (gtk_toggle_button_get_active (button))
-    {
-        g_value_set_boolean (&value, TRUE);
-    }
-    else
-    {
-        g_value_set_boolean (&value, FALSE);
-    }
-
-    g_object_set_property (G_OBJECT (dialog->priv->settings), "preload-images", &value);
-
-    g_value_unset (&value);
-}
-
-static void
-cb_rstto_preferences_dialog_cache_spin_button_value_changed (GtkSpinButton *button, 
-                                                                gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    GValue value = {0, };
-    g_value_init (&value, G_TYPE_UINT);
-
-    g_value_set_uint (&value, (guint)gtk_spin_button_get_value (button));
-
-    g_object_set_property (G_OBJECT (dialog->priv->settings), "cache-size", &value);
-
-    g_value_unset (&value);
-}
-
-static void
-cb_rstto_preferences_dialog_image_preview_toggled (GtkToggleButton *button, 
-                                                      gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    rstto_settings_set_boolean_property (dialog->priv->settings, "show-preview", gtk_toggle_button_get_active (button));
-}
-
-static void
-cb_rstto_preferences_dialog_no_scrollwheel_action_radio_button_toggled (GtkToggleButton *button, 
-                                                                        gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    if (gtk_toggle_button_get_active (button))
-    {
-        rstto_settings_set_string_property (dialog->priv->settings, "scrollwheel-primary-action", "none");
-    }
-}
-
-static void
-cb_rstto_preferences_dialog_zoom_scrollwheel_action_radio_button_toggled (GtkToggleButton *button, 
-                                                                        gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    if (gtk_toggle_button_get_active (button))
-    {
-        rstto_settings_set_string_property (dialog->priv->settings, "scrollwheel-primary-action", "zoom");
-    }
-}
-
-static void
-cb_rstto_preferences_dialog_switch_scrollwheel_action_radio_button_toggled (GtkToggleButton *button, 
-                                                                        gpointer user_data)
-{
-    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
-
-    if (gtk_toggle_button_get_active (button))
-    {
-        rstto_settings_set_string_property (dialog->priv->settings, "scrollwheel-primary-action", "switch");
-    }
+    rstto_settings_set_boolean_property (dialog->priv->settings, "revert-zoom-direction", gtk_toggle_button_get_active(button));
 }
 
 static void
@@ -666,19 +445,37 @@ cb_rstto_preferences_dialog_hide_thumbnails_fullscreen_check_button_toggled (
 }
 
 static void
-cb_rstto_preferences_dialog_open_entire_folder_check_button_toggled (GtkToggleButton *button, 
+cb_open_entire_folder_check_button_toggled (GtkToggleButton *button, 
                                                       gpointer user_data)
 {
     RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
 
-    rstto_settings_set_boolean_property (dialog->priv->settings, "open-entire-folder", gtk_toggle_button_get_active(button));
+    rstto_settings_set_boolean_property (
+            dialog->priv->settings,
+            "open-entire-folder",
+            gtk_toggle_button_get_active(button));
 }
 
 static void
-cb_rstto_preferences_dialog_wrap_images_check_button_toggled (GtkToggleButton *button, 
+cb_wrap_images_check_button_toggled (GtkToggleButton *button, 
                                                       gpointer user_data)
 {
     RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
 
-    rstto_settings_set_boolean_property (dialog->priv->settings, "wrap-images", gtk_toggle_button_get_active(button));
+    rstto_settings_set_boolean_property (
+            dialog->priv->settings,
+            "wrap-images",
+            gtk_toggle_button_get_active(button));
+}
+
+static void
+cb_maximize_on_startup_check_button_toggled (GtkToggleButton *button, 
+                                                      gpointer user_data)
+{
+    RsttoPreferencesDialog *dialog = RSTTO_PREFERENCES_DIALOG (user_data);
+
+    rstto_settings_set_boolean_property (
+            dialog->priv->settings,
+            "maximize-on-startup",
+            gtk_toggle_button_get_active(button));
 }
