@@ -24,7 +24,6 @@
 #include <libxfce4ui/libxfce4ui.h>
 #include <libexif/exif-data.h>
 
-#include "image.h"
 #include "image_list.h"
 #include "thumbnail.h"
 #include "thumbnail_bar.h"
@@ -72,9 +71,9 @@ static void
 rstto_thumbnail_bar_unrealize(GtkWidget *widget);
 
 static void
-cb_rstto_thumbnail_bar_image_list_new_image (RsttoImageList *image_list, RsttoImage *image, gpointer user_data);
+cb_rstto_thumbnail_bar_image_list_new_file (RsttoImageList *image_list, GFile *file, gpointer user_data);
 static void
-cb_rstto_thumbnail_bar_image_list_remove_image (RsttoImageList *image_list, RsttoImage *image, gpointer user_data);
+cb_rstto_thumbnail_bar_image_list_remove_file (RsttoImageList *image_list, GFile *file, gpointer user_data);
 static void
 cb_rstto_thumbnail_bar_image_list_remove_all (RsttoImageList *image_list, gpointer user_data);
 void
@@ -196,14 +195,6 @@ rstto_thumbnail_bar_class_init(RsttoThumbnailBarClass *bar_class)
 		0, G_MAXINT, 0,
 		G_PARAM_READABLE));
 
-	gtk_widget_class_install_style_property (widget_class,
-		g_param_spec_int ("film-border-width",
-		_("filmstrip width"),
-		_("the width of the thumbnail-bar film-strip"),
-		0, G_MAXINT, 0,
-		G_PARAM_READABLE));
-
-
 }
 
 static void
@@ -211,12 +202,10 @@ rstto_thumbnail_bar_size_request(GtkWidget *widget, GtkRequisition *requisition)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR(widget);
     gint border_width;
-    gint film_border_width = bar->film_border_width;
     GList *iter;
 	GtkRequisition child_requisition;
 
     gtk_widget_style_get (widget, "border-width", &border_width, NULL);
-    gtk_widget_style_get (widget, "film-border-width", &film_border_width, NULL);
 
     requisition->height = 70;
     requisition->width = 70;
@@ -231,18 +220,17 @@ rstto_thumbnail_bar_size_request(GtkWidget *widget, GtkRequisition *requisition)
     switch (bar->priv->orientation)
     {
         case GTK_ORIENTATION_HORIZONTAL:
-            requisition->height += ((border_width * 2) + (film_border_width * 2));
+            requisition->height += (border_width * 2);
             requisition->width += (border_width * 2);
             break;
         case GTK_ORIENTATION_VERTICAL:
             requisition->height += (border_width * 2);
-            requisition->width += ((border_width * 2) + (film_border_width * 2));
+            requisition->width += (border_width * 2);
             break;
     }
 
 	widget->requisition = *requisition;
     GTK_CONTAINER(bar)->border_width = border_width;
-    bar->film_border_width = film_border_width;
 }
 
 static void
@@ -250,13 +238,12 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR(widget);
     gint border_width = GTK_CONTAINER(bar)->border_width;
-    gint film_border_width = bar->film_border_width;
     gint spacing = 0;
     GtkAllocation child_allocation;
     GtkRequisition child_requisition;
     GList *iter = bar->priv->thumbs;
 
-    RsttoImage *image = NULL;
+    GFile *file = NULL;
 
 	gtk_widget_style_get(widget, "spacing", &spacing, NULL);
     widget->allocation = *allocation;
@@ -280,7 +267,6 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
     switch(bar->priv->orientation)
     {
         case GTK_ORIENTATION_HORIZONTAL:
-            child_allocation.y += film_border_width;
             if (bar->priv->auto_center == TRUE)
             {
                 bar->priv->offset = 0 - (allocation->width / 2);
@@ -288,7 +274,7 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
             while(iter)
             {
                 gtk_widget_get_child_requisition(GTK_WIDGET(iter->data), &child_requisition);
-                allocation->height = MAX(child_requisition.height + (border_width * 2) + (film_border_width * 2), allocation->height);
+                allocation->height = MAX(child_requisition.height + (border_width * 2), allocation->height);
 
                 if (bar->priv->auto_center == TRUE)
                 {
@@ -312,7 +298,7 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
             while(iter)
             {
                 gtk_widget_get_child_requisition(GTK_WIDGET(iter->data), &child_requisition);
-                child_allocation.height = allocation->height - (border_width * 2) - (film_border_width * 2);
+                child_allocation.height = allocation->height - (border_width * 2);
                 child_allocation.width = child_allocation.height;
 
                 if ((child_allocation.x < (allocation->x + allocation->width)) &&
@@ -322,12 +308,13 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
                     gtk_widget_size_allocate(GTK_WIDGET(iter->data), &child_allocation);
 
                     /* Do thumbnailing stuff */
-                    rstto_thumbnailer_queue_image (bar->priv->thumbnailer, iter->data);
+                    rstto_thumbnailer_queue_thumbnail (bar->priv->thumbnailer, iter->data);
                 }
                 else
                 {
                     gtk_widget_set_child_visible(GTK_WIDGET(iter->data), FALSE);
-                    rstto_thumbnailer_dequeue_image (bar->priv->thumbnailer, iter->data);
+
+                    rstto_thumbnailer_dequeue_thumbnail (bar->priv->thumbnailer, iter->data);
                 }
 
                 child_allocation.x += child_allocation.width + spacing;
@@ -335,7 +322,6 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
             }
             break;
         case GTK_ORIENTATION_VERTICAL:
-            child_allocation.x += film_border_width;
             if (bar->priv->auto_center == TRUE)
             {
                 bar->priv->offset = 0 - (allocation->height / 2);
@@ -343,7 +329,7 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
             while(iter)
             {
                 gtk_widget_get_child_requisition(GTK_WIDGET(iter->data), &child_requisition);
-                allocation->width = MAX(child_requisition.width + (border_width * 2) + (film_border_width * 2), allocation->width);
+                allocation->width = MAX(child_requisition.width + (border_width * 2), allocation->width);
 
                 if (bar->priv->auto_center == TRUE)
                 {
@@ -368,7 +354,7 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
             {
 
                 gtk_widget_get_child_requisition(GTK_WIDGET(iter->data), &child_requisition);
-                child_allocation.width = allocation->width - (border_width * 2) - (film_border_width * 2);
+                child_allocation.width = allocation->width - (border_width * 2);
                 child_allocation.height = child_allocation.width;
 
                 if (child_allocation.y < (allocation->y + allocation->height))
@@ -377,12 +363,12 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
                     gtk_widget_size_allocate(GTK_WIDGET(iter->data), &child_allocation);
 
                     /* Do thumbnailing stuff */
-                    rstto_thumbnailer_queue_image (bar->priv->thumbnailer, iter->data);
+                    rstto_thumbnailer_queue_thumbnail (bar->priv->thumbnailer, iter->data);
                 }
                 else
                 {
                     gtk_widget_set_child_visible(GTK_WIDGET(iter->data), FALSE);
-                    rstto_thumbnailer_dequeue_image (bar->priv->thumbnailer, iter->data);
+                    rstto_thumbnailer_dequeue_thumbnail (bar->priv->thumbnailer, iter->data);
                 }
 
                 gtk_widget_size_allocate(GTK_WIDGET(iter->data), &child_allocation);
@@ -404,7 +390,6 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
 
     GdkGC *gc = gdk_gc_new(GDK_DRAWABLE(widget->window));
     gint border_width = GTK_CONTAINER(bar)->border_width;
-    gint film_border_width = bar->film_border_width;
     gint i = 0;
     GdkColor color, dot_color, bar_color;
     color.red= 0;
@@ -431,46 +416,6 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
     gdk_colormap_alloc_color (gdk_gc_get_colormap (gc), &bar_color, FALSE, TRUE);
     gdk_gc_set_rgb_fg_color (gc, &color);
 
-    switch (bar->priv->orientation)
-    {
-        case GTK_ORIENTATION_HORIZONTAL:
-            if (film_border_width > 0)
-            {
-                n_ex->area.y += film_border_width;
-
-                gdk_draw_rectangle(GDK_DRAWABLE(widget->window), gc, TRUE, 0, 0, widget->allocation.width, film_border_width);
-                gdk_draw_rectangle(GDK_DRAWABLE(widget->window), gc, TRUE, 0, widget->allocation.height - film_border_width, widget->allocation.width, film_border_width);
-                gdk_gc_set_rgb_fg_color (gc, &dot_color);
-                for (; i < widget->allocation.width; i+=film_border_width)
-                {
-                    gdk_draw_rectangle (GDK_DRAWABLE (widget->window), gc, TRUE, 2+i, 2, (gint)((gdouble)film_border_width / 2.0), (gint)((gdouble)film_border_width / 2.0));
-                    gdk_draw_rectangle (GDK_DRAWABLE (widget->window), gc, TRUE, 2+i,
-                                        widget->allocation.height - (gint)((gdouble)film_border_width / 4.0 * 3.0),
-                                        film_border_width/2, film_border_width/2);
-                }
-            }
-            break;
-
-        case GTK_ORIENTATION_VERTICAL:
-
-            if (film_border_width > 0)
-            {
-                n_ex->area.x += film_border_width;
-                gdk_draw_rectangle(GDK_DRAWABLE(widget->window), gc, TRUE, 0, 0, film_border_width, widget->allocation.height);
-                gdk_draw_rectangle(GDK_DRAWABLE(widget->window), gc, TRUE, widget->allocation.width - film_border_width, 0, film_border_width, widget->allocation.height);
-                gdk_gc_set_rgb_fg_color (gc, &dot_color);
-                for (; i < widget->allocation.height; i+=film_border_width)
-                {
-                    gdk_draw_rectangle (GDK_DRAWABLE (widget->window), gc, TRUE, 2, 2+i, film_border_width / 2, film_border_width / 2);
-                    gdk_draw_rectangle (GDK_DRAWABLE (widget->window), gc, TRUE,
-                                        widget->allocation.width - (gint)((gdouble)film_border_width / 4.0 * 3.0),
-                                        2+i,
-                                        film_border_width/2, film_border_width/2);
-                }
-            }
-            break;
-    }
-
     while(iter)
     {
 
@@ -623,8 +568,8 @@ rstto_thumbnail_bar_set_image_list (RsttoThumbnailBar *bar, RsttoImageList *nav)
 
     if (bar->priv->image_list)
     {
-        g_signal_connect (G_OBJECT (bar->priv->image_list), "new-image", G_CALLBACK (cb_rstto_thumbnail_bar_image_list_new_image), bar);
-        g_signal_connect (G_OBJECT (bar->priv->image_list), "remove-image", G_CALLBACK (cb_rstto_thumbnail_bar_image_list_remove_image), bar);
+        g_signal_connect (G_OBJECT (bar->priv->image_list), "new-image", G_CALLBACK (cb_rstto_thumbnail_bar_image_list_new_file), bar);
+        g_signal_connect (G_OBJECT (bar->priv->image_list), "remove-image", G_CALLBACK (cb_rstto_thumbnail_bar_image_list_remove_file), bar);
         g_signal_connect (G_OBJECT (bar->priv->image_list), "remove-all", G_CALLBACK (cb_rstto_thumbnail_bar_image_list_remove_all), bar);
         g_object_ref (nav);
     }
@@ -678,7 +623,7 @@ rstto_thumbnail_bar_remove(GtkContainer *container, GtkWidget *child)
 
 	widget_was_visible = GTK_WIDGET_VISIBLE(child);
 
-    rstto_thumbnailer_dequeue_image (bar->priv->thumbnailer, rstto_thumbnail_get_image(RSTTO_THUMBNAIL(child)));
+    rstto_thumbnailer_dequeue_thumbnail (bar->priv->thumbnailer, RSTTO_THUMBNAIL(child));
 
     bar->priv->thumbs = g_list_remove(bar->priv->thumbs, child);
 
@@ -711,8 +656,8 @@ static gint
 cb_rstto_thumbnail_bar_compare (GtkWidget *a, GtkWidget *b, gpointer user_data)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR (user_data);
-    RsttoImage *a_i = rstto_thumbnail_get_image (RSTTO_THUMBNAIL (a));
-    RsttoImage *b_i = rstto_thumbnail_get_image (RSTTO_THUMBNAIL (b));
+    GFile *a_i = rstto_thumbnail_get_file (RSTTO_THUMBNAIL (a));
+    GFile *b_i = rstto_thumbnail_get_file (RSTTO_THUMBNAIL (b));
 
     return rstto_image_list_get_compare_func (bar->priv->image_list) (a_i, b_i);
 }
@@ -920,21 +865,21 @@ cb_rstto_thumbnail_bar_image_list_iter_changed (RsttoImageListIter *iter, gpoint
 }
 
 static void
-cb_rstto_thumbnail_bar_image_list_new_image (RsttoImageList *image_list, RsttoImage *image, gpointer user_data)
+cb_rstto_thumbnail_bar_image_list_new_file (RsttoImageList *image_list, GFile *file, gpointer user_data)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR (user_data);
     GtkWidget *thumb;
     GList *iter;
 
-    g_return_if_fail (rstto_image_list_iter_find_image (bar->priv->internal_iter, image));
+    g_return_if_fail (rstto_image_list_iter_find_file (bar->priv->internal_iter, file));
 
     for (iter = bar->priv->thumbs; iter != NULL; iter = g_list_next (iter))
     {
-        if (image == rstto_thumbnail_get_image (iter->data))
+        if (g_file_equal(file,rstto_thumbnail_get_file (iter->data)))
             return;
     }
 
-    thumb = rstto_thumbnail_new (image);
+    thumb = rstto_thumbnail_new (file);
 
     gtk_container_add (GTK_CONTAINER (bar), thumb);
     gtk_widget_show_all (thumb);
@@ -946,14 +891,14 @@ cb_rstto_thumbnail_bar_image_list_new_image (RsttoImageList *image_list, RsttoIm
 }
 
 static void
-cb_rstto_thumbnail_bar_image_list_remove_image (RsttoImageList *image_list, RsttoImage *image, gpointer user_data)
+cb_rstto_thumbnail_bar_image_list_remove_file (RsttoImageList *image_list, GFile *file, gpointer user_data)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR (user_data);
     GList *iter = bar->priv->thumbs;
 
     while (iter)
     {
-        if (rstto_thumbnail_get_image (iter->data) == image)
+        if (g_file_equal(rstto_thumbnail_get_file(iter->data), file))
         {
             GtkWidget *widget = iter->data;
             gtk_container_remove (GTK_CONTAINER (bar), widget);
